@@ -1,4 +1,4 @@
-# Copyright 2018-2020 Streamlit Inc.
+# Copyright 2018-2021 Streamlit Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -157,9 +157,11 @@ def _create_option(
         replaced_by=replaced_by,
         type_=type_,
     )
-    assert option.section in _section_descriptions, (
-        'Section "%s" must be one of %s.'
-        % (option.section, ", ".join(_section_descriptions.keys()),)
+    assert (
+        option.section in _section_descriptions
+    ), 'Section "%s" must be one of %s.' % (
+        option.section,
+        ", ".join(_section_descriptions.keys()),
     )
     assert key not in _config_options, 'Cannot define option "%s" twice.' % key
     _config_options[key] = option
@@ -626,6 +628,7 @@ _create_option(
     default_val="True",
     scriptable="True",
     type_=bool,
+    expiration_date="2021-01-06",
 )
 
 _create_option(
