@@ -1,4 +1,4 @@
-# Copyright 2018-2020 Streamlit Inc.
+# Copyright 2018-2021 Streamlit Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 """Allows us to create and absorb changes (aka Deltas) to elements."""
 from typing import Optional, Iterable, List
 
+import streamlit as st
 from streamlit import caching
 from streamlit import cursor
 from streamlit import type_util
@@ -35,8 +36,8 @@ from streamlit.elements.text import TextMixin
 from streamlit.elements.alert import AlertMixin
 from streamlit.elements.json import JsonMixin
 from streamlit.elements.doc_string import HelpMixin
-from streamlit.elements.exception_proto import ExceptionMixin
-from streamlit.elements.data_frame_proto import DataFrameMixin
+from streamlit.elements.exception import ExceptionMixin
+from streamlit.elements.data_frame import DataFrameMixin
 from streamlit.elements.altair import AltairMixin
 from streamlit.elements.bokeh_chart import BokehMixin
 from streamlit.elements.graphviz_chart import GraphvizMixin
@@ -44,8 +45,8 @@ from streamlit.elements.plotly_chart import PlotlyMixin
 from streamlit.elements.vega_lite import VegaLiteMixin
 from streamlit.elements.deck_gl_json_chart import PydeckMixin
 from streamlit.elements.map import MapMixin
-from streamlit.elements.iframe_proto import IframeMixin
-from streamlit.elements.media_proto import MediaMixin
+from streamlit.elements.iframe import IframeMixin
+from streamlit.elements.media import MediaMixin
 from streamlit.elements.checkbox import CheckboxMixin
 from streamlit.elements.multiselect import MultiSelectMixin
 from streamlit.elements.radio import RadioMixin
@@ -59,9 +60,10 @@ from streamlit.elements.color_picker import ColorPickerMixin
 from streamlit.elements.file_uploader import FileUploaderMixin
 from streamlit.elements.select_slider import SelectSliderMixin
 from streamlit.elements.slider import SliderMixin
-from streamlit.elements.image_proto import ImageMixin
+from streamlit.elements.image import ImageMixin
 from streamlit.elements.pyplot import PyplotMixin
 from streamlit.elements.write import WriteMixin
+from streamlit.elements.layouts import LayoutsMixin
 
 LOGGER = get_logger(__name__)
 
@@ -91,6 +93,7 @@ class DeltaGenerator(
     HelpMixin,
     IframeMixin,
     ImageMixin,
+    LayoutsMixin,
     MarkdownMixin,
     MapMixin,
     MediaMixin,
@@ -298,9 +301,9 @@ class DeltaGenerator(
         This way, users can (say) use st.image with a stream of different images,
         and Streamlit will expire the older images and replace them in place.
         """
-        # Switch to the active DeltaGenerator, in case we're in a `with` block.
-        self = self._active_dg
-        return str(self._cursor.delta_path) if self._cursor is not None else "[]"
+        # Operate on the active DeltaGenerator, in case we're in a `with` block.
+        dg = self._active_dg
+        return str(dg._cursor.delta_path) if dg._cursor is not None else "[]"
 
     def _enqueue(
         self,
@@ -333,10 +336,13 @@ class DeltaGenerator(
             element.
 
         """
-        # Switch to the active DeltaGenerator, in case we're in a `with` block.
-        self = self._active_dg
+        # Operate on the active DeltaGenerator, in case we're in a `with` block.
+        dg = self._active_dg
         # Warn if we're called from within an @st.cache function
-        caching.maybe_show_cached_st_function_warning(self, delta_type)
+        caching.maybe_show_cached_st_function_warning(dg, delta_type)
+
+        # Warn if an element is being changed but the user isn't running the streamlit server.
+        st._maybe_print_use_warning()
 
         # Some elements have a method.__name__ != delta_type in proto.
         # This really matters for line_chart, bar_chart & area_chart,
@@ -353,8 +359,8 @@ class DeltaGenerator(
 
         # Only enqueue message and fill in metadata if there's a container.
         msg_was_enqueued = False
-        if self._root_container is not None and self._cursor is not None:
-            msg.metadata.delta_path[:] = self._cursor.delta_path
+        if dg._root_container is not None and dg._cursor is not None:
+            msg.metadata.delta_path[:] = dg._cursor.delta_path
 
             if element_width is not None:
                 msg.metadata.element_dimension_spec.width = element_width
@@ -368,178 +374,34 @@ class DeltaGenerator(
             # Get a DeltaGenerator that is locked to the current element
             # position.
             new_cursor = (
-                self._cursor.get_locked_cursor(
+                dg._cursor.get_locked_cursor(
                     delta_type=delta_type, last_index=last_index
                 )
-                if self._cursor is not None
+                if dg._cursor is not None
                 else None
             )
 
             output_dg = DeltaGenerator(
-                root_container=self._root_container,
+                root_container=dg._root_container,
                 cursor=new_cursor,
-                parent=self,
+                parent=dg,
             )
         else:
             # If the message was not enqueued, just return self since it's a
             # no-op from the point of view of the app.
-            output_dg = self
+            output_dg = dg
 
         return _value_or_dg(return_value, output_dg)
 
-    def beta_container(self) -> "DeltaGenerator":
-        """Insert a multi-element container.
-
-        Inserts an invisible container into your app that can be used to hold
-        multiple elements. This allows you to, for example, insert multiple
-        elements into your app out of order.
-
-        To add elements to the returned container, you can use "with" notation
-        (preferred) or just call methods directly on the returned object. See
-        examples below.
-
-        Examples
-        --------
-
-        Inserting elements using "with" notation:
-
-        >>> with st.beta_container():
-        ...    st.write("This is inside the container")
-        ...
-        ...    # You can call any Streamlit command, including custom components:
-        ...    st.bar_chart(np.random.randn(50, 3))
-        ...
-        >>> st.write("This is outside the container")
-
-        .. output ::
-            https://static.streamlit.io/0.66.0-Wnid/index.html?id=Qj8PY3v3L8dgVjjQCreHux
-            height: 420px
-
-        Inserting elements out of order:
-
-        >>> container = st.beta_container()
-        >>> container.write("This is inside the container")
-        >>> st.write("This is outside the container")
-        >>>
-        >>> # Now insert some more in the container
-        >>> container.write("This is inside too")
-
-        .. output ::
-            https://static.streamlit.io/0.66.0-Wnid/index.html?id=GsFVF5QYT3Ljr6jQjErPqL
-        """
-        return self._block()
-
-    # TODO: Enforce that columns are not nested or in Sidebar
-    def beta_columns(self, spec) -> List["DeltaGenerator"]:
-        """Insert containers laid out as side-by-side columns.
-
-        Inserts a number of multi-element containers laid out side-by-side and
-        returns a list of container objects.
-
-        To add elements to the returned containers, you can use "with" notation
-        (preferred) or just call methods directly on the returned object. See
-        examples below.
-
-        .. warning::
-            Currently, you may not put columns inside another column.
-
-        Parameters
-        ----------
-        spec : int or list of numbers
-            If an int
-                Specifies the number of columns to insert, and all columns
-                have equal width.
-
-            If a list of numbers
-                Creates a column for each number, and each
-                column's width is proportional to the number provided. Numbers can
-                be ints or floats, but they must be positive.
-
-                For example, `st.beta_columns([3, 1, 2])` creates 3 columns where
-                the first column is 3 times the width of the second, and the last
-                column is 2 times that width.
-
-        Returns
-        -------
-        list of containers
-            A list of container objects.
-
-        Examples
-        --------
-
-        You can use `with` notation to insert any element into a column:
-
-        >>> col1, col2, col3 = st.beta_columns(3)
-        >>>
-        >>> with col1:
-        ...    st.header("A cat")
-        ...    st.image("https://static.streamlit.io/examples/cat.jpg", use_column_width=True)
-        ...
-        >>> with col2:
-        ...    st.header("A dog")
-        ...    st.image("https://static.streamlit.io/examples/dog.jpg", use_column_width=True)
-        ...
-        >>> with col3:
-        ...    st.header("An owl")
-        ...    st.image("https://static.streamlit.io/examples/owl.jpg", use_column_width=True)
-
-        .. output ::
-            https://static.streamlit.io/0.66.0-Wnid/index.html?id=VW45Va5XmSKed2ayzf7vYa
-            height: 550px
-
-        Or you can just call methods directly in the returned objects:
-
-        >>> col1, col2 = st.beta_columns([3, 1])
-        >>> data = np.random.randn(10, 1)
-        >>>
-        >>> col1.subheader("A wide column with a chart")
-        >>> col1.line_chart(data)
-        >>>
-        >>> col2.subheader("A narrow column with the data")
-        >>> col2.write(data)
-
-        .. output ::
-            https://static.streamlit.io/0.66.0-Wnid/index.html?id=XSQ6VkonfGcT2AyNYMZN83
-            height: 400px
-
-        """
-        weights = spec
-        weights_exception = StreamlitAPIException(
-            "The input argument to st.beta_columns must be either a "
-            + "positive integer or a list of positive numeric weights. "
-            + "See [documentation](https://docs.streamlit.io/en/stable/api.html#streamlit.beta_columns) "
-            + "for more information."
-        )
-
-        if isinstance(weights, int):
-            # If the user provided a single number, expand into equal weights.
-            # E.g. (1,) * 3 => (1, 1, 1)
-            # NOTE: A negative/zero spec will expand into an empty tuple.
-            weights = (1,) * weights
-
-        if len(weights) == 0 or any(weight <= 0 for weight in weights):
-            raise weights_exception
-
-        def column_proto(weight):
-            col_proto = Block_pb2.Block()
-            col_proto.column.weight = weight
-            col_proto.allow_empty = True
-            return col_proto
-
-        horiz_proto = Block_pb2.Block()
-        horiz_proto.horizontal.total_weight = sum(weights)
-        row = self._block(horiz_proto)
-        return [row._block(column_proto(w)) for w in weights]
-
-    # Internal block element, to hide the 'layout' param from our users.
+    # Internal block element, used for e.g. containers, expanders, columns
     def _block(self, block_proto=Block_pb2.Block()) -> "DeltaGenerator":
-        # Switch to the active DeltaGenerator, in case we're in a `with` block.
-        self = self._active_dg
+        # Operate on the active DeltaGenerator, in case we're in a `with` block.
+        dg = self._active_dg
 
         # Prevent nested columns & expanders by checking all parents.
         block_type = block_proto.WhichOneof("type")
         # Convert the generator to a list, so we can use it multiple times.
-        parent_block_types = frozenset(self._parent_block_types)
+        parent_block_types = frozenset(dg._parent_block_types)
         if block_type == "column" and block_type in parent_block_types:
             raise StreamlitAPIException(
                 "Columns may not be nested inside other columns."
@@ -549,85 +411,33 @@ class DeltaGenerator(
                 "Expanders may not be nested inside other expanders."
             )
 
-        if self._root_container is None or self._cursor is None:
-            return self
+        if dg._root_container is None or dg._cursor is None:
+            return dg
 
         msg = ForwardMsg_pb2.ForwardMsg()
-        msg.metadata.delta_path[:] = self._cursor.delta_path
+        msg.metadata.delta_path[:] = dg._cursor.delta_path
         msg.delta.add_block.CopyFrom(block_proto)
 
         # Normally we'd return a new DeltaGenerator that uses the locked cursor
         # below. But in this case we want to return a DeltaGenerator that uses
         # a brand new cursor for this new block we're creating.
         block_cursor = cursor.RunningCursor(
-            root_container=self._root_container,
-            parent_path=self._cursor.parent_path + (self._cursor.index,),
+            root_container=dg._root_container,
+            parent_path=dg._cursor.parent_path + (dg._cursor.index,),
         )
         block_dg = DeltaGenerator(
-            root_container=self._root_container,
+            root_container=dg._root_container,
             cursor=block_cursor,
-            parent=self,
+            parent=dg,
             block_type=block_type,
         )
 
         # Must be called to increment this cursor's index.
-        self._cursor.get_locked_cursor(last_index=None)
+        dg._cursor.get_locked_cursor(last_index=None)
         _enqueue_message(msg)
 
         return block_dg
 
-    def beta_expander(self, label=None, expanded=False) -> "DeltaGenerator":
-        """Insert a multi-element container that can be expanded/collapsed.
-
-        Inserts a container into your app that can be used to hold multiple elements
-        and can be expanded or collapsed by the user. When collapsed, all that is
-        visible is the provided label.
-
-        To add elements to the returned container, you can use "with" notation
-        (preferred) or just call methods directly on the returned object. See
-        examples below.
-
-        .. warning::
-            Currently, you may not put expanders inside another expander.
-
-        Parameters
-        ----------
-        label : str
-            A string to use as the header for the expander.
-        expanded : bool
-            If True, initializes the expander in "expanded" state. Defaults to
-            False (collapsed).
-
-        Examples
-        --------
-        >>> st.line_chart({"data": [1, 5, 2, 6, 2, 1]})
-        >>>
-        >>> with st.beta_expander("See explanation"):
-        ...     st.write(\"\"\"
-        ...         The chart above shows some numbers I picked for you.
-        ...         I rolled actual dice for these, so they're *guaranteed* to
-        ...         be random.
-        ...     \"\"\")
-        ...     st.image("https://static.streamlit.io/examples/dice.jpg")
-
-        .. output ::
-            https://static.streamlit.io/0.66.0-2BLtg/index.html?id=7v2tgefVbW278gemvYrRny
-            height: 750px
-
-        """
-        if label is None:
-            raise StreamlitAPIException("A label is required for an expander")
-
-        expandable_proto = Block_pb2.Block.Expandable()
-        expandable_proto.expanded = expanded
-        expandable_proto.label = label
-
-        block_proto = Block_pb2.Block()
-        block_proto.allow_empty = True
-        block_proto.expandable.CopyFrom(expandable_proto)
-
-        return self._block(block_proto=block_proto)
-
     def add_rows(self, data=None, **kwargs):
         """Concatenate a dataframe to the bottom of the current one.
 
@@ -720,9 +530,9 @@ class DeltaGenerator(
         msg = ForwardMsg_pb2.ForwardMsg()
         msg.metadata.delta_path[:] = self._cursor.delta_path
 
-        import streamlit.elements.data_frame_proto as data_frame_proto
+        import streamlit.elements.data_frame as data_frame
 
-        data_frame_proto.marshall_data_frame(data, msg.delta.add_rows.data)
+        data_frame.marshall_data_frame(data, msg.delta.add_rows.data)
 
         if name:
             msg.delta.add_rows.name = name
@@ -735,7 +545,7 @@ class DeltaGenerator(
 
 def _maybe_melt_data_for_add_rows(data, delta_type, last_index):
     import pandas as pd
-    import streamlit.elements.data_frame_proto as data_frame_proto
+    import streamlit.elements.data_frame as data_frame
 
     # For some delta types we have to reshape the data structure
     # otherwise the input data and the actual data used
