@@ -1,9 +1,26 @@
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+from typing import cast
+
+import streamlit
 from streamlit.proto.Checkbox_pb2 import Checkbox as CheckboxProto
-from .utils import _get_widget_ui_value
+from .utils import register_widget
 
 
 class CheckboxMixin:
-    def checkbox(dg, label, value=False, key=None):
+    def checkbox(self, label, value=False, key=None):
         """Display a checkbox widget.
 
         Parameters
@@ -36,6 +53,11 @@ class CheckboxMixin:
         checkbox_proto.label = label
         checkbox_proto.default = bool(value)
 
-        ui_value = _get_widget_ui_value("checkbox", checkbox_proto, user_key=key)
+        ui_value = register_widget("checkbox", checkbox_proto, user_key=key)
         current_value = ui_value if ui_value is not None else value
-        return dg._enqueue("checkbox", checkbox_proto, bool(current_value))  # type: ignore
+        return self.dg._enqueue("checkbox", checkbox_proto, bool(current_value))
+
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
