@@ -1,18 +1,30 @@
-import re
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
-from streamlit.proto.ColorPicker_pb2 import ColorPicker as ColorPickerProto
+import re
+from typing import cast
+
+import streamlit
 from streamlit.errors import StreamlitAPIException
-from .utils import _get_widget_ui_value
+from streamlit.proto.ColorPicker_pb2 import ColorPicker as ColorPickerProto
+from .utils import register_widget
 
 
 class ColorPickerMixin:
-    def color_picker(dg, label, value=None, key=None):
+    def color_picker(self, label, value=None, key=None):
         """Display a color picker widget.
 
-        Note: This is a beta feature. See
-        https://docs.streamlit.io/en/latest/api.html#pre-release-features for more
-        information.
-
         Parameters
         ----------
         label : str
@@ -67,8 +79,11 @@ class ColorPickerMixin:
         color_picker_proto.label = label
         color_picker_proto.default = str(value)
 
-        ui_value = _get_widget_ui_value(
-            "color_picker", color_picker_proto, user_key=key
-        )
+        ui_value = register_widget("color_picker", color_picker_proto, user_key=key)
         current_value = ui_value if ui_value is not None else value
-        return dg._enqueue("color_picker", color_picker_proto, str(current_value))  # type: ignore
+        return self.dg._enqueue("color_picker", color_picker_proto, str(current_value))
+
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
