@@ -1,16 +1,30 @@
-from streamlit import config
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
+from typing import cast
+
+import streamlit
+from streamlit import config
 from streamlit.errors import StreamlitDeprecationWarning
 from streamlit.proto.FileUploader_pb2 import FileUploader as FileUploaderProto
 from streamlit.report_thread import get_report_ctx
-from .utils import NoValue, _set_widget_id
+from .utils import NoValue, register_widget
 from ..uploaded_file_manager import UploadedFile
 
 
 class FileUploaderMixin:
-    def file_uploader(
-        dg, label, type=None, accept_multiple_files=False, key=None, **kwargs
-    ):
+    def file_uploader(self, label, type=None, accept_multiple_files=False, key=None):
         """Display a file uploader widget.
         By default, uploaded files are limited to 200MB. You can configure
         this using the `server.maxUploadSize` config option.
@@ -55,11 +69,11 @@ class FileUploaderMixin:
         >>> uploaded_file = st.file_uploader("Choose a file")
         >>> if uploaded_file is not None:
         ...     # To read file as bytes:
-        ...     bytes_data = uploaded_file.read()
+        ...     bytes_data = uploaded_file.getvalue()
         ...     st.write(bytes_data)
         >>>
         ...     # To convert to a string based IO:
-        ...     stringio = StringIO(uploaded_file.decode("utf-8"))
+        ...     stringio = StringIO(uploaded_file.getvalue().decode("utf-8"))
         ...     st.write(stringio)
         >>>
         ...     # To read file as string:
@@ -90,14 +104,6 @@ class FileUploaderMixin:
                 for file_type in type
             ]
 
-        has_encoding = "encoding" in kwargs
-        show_deprecation_warning = config.get_option(
-            "deprecation.showfileUploaderEncoding"
-        )
-
-        if show_deprecation_warning and has_encoding:
-            dg.exception(FileUploaderEncodingWarning())  # type: ignore
-
         file_uploader_proto = FileUploaderProto()
         file_uploader_proto.label = label
         file_uploader_proto.type[:] = type if type is not None else []
@@ -105,7 +111,7 @@ class FileUploaderMixin:
             "server.maxUploadSize"
         )
         file_uploader_proto.multiple_files = accept_multiple_files
-        _set_widget_id("file_uploader", file_uploader_proto, user_key=key)
+        register_widget("file_uploader", file_uploader_proto, user_key=key)
 
         file_recs = None
         ctx = get_report_ctx()
@@ -120,26 +126,9 @@ class FileUploaderMixin:
             files = [UploadedFile(rec) for rec in file_recs]
             return_value = files if accept_multiple_files else files[0]
 
-        return dg._enqueue("file_uploader", file_uploader_proto, return_value)  # type: ignore
+        return self.dg._enqueue("file_uploader", file_uploader_proto, return_value)
 
-
-class FileUploaderEncodingWarning(StreamlitDeprecationWarning):
-    def __init__(self):
-        msg = self._get_message()
-        config_option = "deprecation.showfileUploaderEncoding"
-        super(FileUploaderEncodingWarning, self).__init__(
-            msg=msg, config_option=config_option
-        )
-
-    def _get_message(self):
-        return """
-The behavior of `st.file_uploader` no longer autodetects the file's encoding.
-This means that _all files_ will be returned as binary buffers. If you need to
-work with a string buffer, you can convert to a StringIO by decoding the binary
-buffer as shown below:
-
-```
-file_buffer = st.file_uploader(...)
-string_io = file_buffer.decode()
-```
-            """
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
