@@ -1,11 +1,28 @@
-from streamlit.proto.MultiSelect_pb2 import MultiSelect as MultiSelectProto
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+from typing import cast
+
+import streamlit
 from streamlit.errors import StreamlitAPIException
+from streamlit.proto.MultiSelect_pb2 import MultiSelect as MultiSelectProto
 from streamlit.type_util import is_type, ensure_iterable
-from .utils import _get_widget_ui_value, NoValue
+from .utils import register_widget
 
 
 class MultiSelectMixin:
-    def multiselect(dg, label, options, default=None, format_func=str, key=None):
+    def multiselect(self, label, options, default=None, format_func=str, key=None):
         """Display a multiselect widget.
         The multiselect widget starts as empty.
 
@@ -86,7 +103,12 @@ class MultiSelectMixin:
         multiselect_proto.default[:] = default_value
         multiselect_proto.options[:] = [str(format_func(option)) for option in options]
 
-        ui_value = _get_widget_ui_value("multiselect", multiselect_proto, user_key=key)
+        ui_value = register_widget("multiselect", multiselect_proto, user_key=key)
         current_value = ui_value.data if ui_value is not None else default_value
         return_value = [options[i] for i in current_value]
-        return dg._enqueue("multiselect", multiselect_proto, return_value)  # type: ignore
+        return self.dg._enqueue("multiselect", multiselect_proto, return_value)
+
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
