@@ -1,14 +1,30 @@
-import numbers
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
-from streamlit.proto.NumberInput_pb2 import NumberInput as NumberInputProto
+import numbers
+from typing import cast
+
+import streamlit
 from streamlit.errors import StreamlitAPIException
 from streamlit.js_number import JSNumber, JSNumberBoundsException
-from .utils import _get_widget_ui_value, NoValue
+from streamlit.proto.NumberInput_pb2 import NumberInput as NumberInputProto
+from .utils import register_widget, NoValue
 
 
 class NumberInputMixin:
     def number_input(
-        dg,
+        self,
         label,
         min_value=None,
         max_value=None,
@@ -39,7 +55,7 @@ class NumberInputMixin:
         format : str or None
             A printf-style format string controlling how the interface should
             display numbers. Output must be purely numeric. This does not impact
-            the return value. Valid formatters: %d %e %f %g %i
+            the return value. Valid formatters: %d %e %f %g %i %u
         key : str
             An optional string to use as the unique key for the widget.
             If this is omitted, a key will be generated for the widget
@@ -59,7 +75,7 @@ class NumberInputMixin:
         """
 
         if isinstance(value, NoValue):
-            if min_value:
+            if min_value is not None:
                 value = min_value
             else:
                 value = 0.0  # We set a float as default
@@ -75,14 +91,20 @@ class NumberInputMixin:
             if format is None:
                 format = "%d" if int_value else "%0.2f"
 
+            # Warn user if they format an int type as a float or vice versa.
             if format in ["%d", "%u", "%i"] and float_value:
-                # Warn user to check if displaying float as int was really intended.
                 import streamlit as st
 
                 st.warning(
-                    "Warning: NumberInput value below is float, but format {} displays as integer.".format(
-                        format
-                    )
+                    "Warning: NumberInput value below has type float,"
+                    f" but format {format} displays as integer."
+                )
+            elif format[-1] == "f" and int_value:
+                import streamlit as st
+
+                st.warning(
+                    "Warning: NumberInput value below has type int so is"
+                    f" displayed as int despite format string {format}."
                 )
 
             if step is None:
@@ -194,9 +216,12 @@ class NumberInputMixin:
         if format is not None:
             number_input_proto.format = format
 
-        ui_value = _get_widget_ui_value(
-            "number_input", number_input_proto, user_key=key
-        )
+        ui_value = register_widget("number_input", number_input_proto, user_key=key)
 
         return_value = ui_value if ui_value is not None else value
-        return dg._enqueue("number_input", number_input_proto, return_value)  # type: ignore
+        return self.dg._enqueue("number_input", number_input_proto, return_value)
+
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
