@@ -1,15 +1,31 @@
-from datetime import date, time, datetime, timedelta, timezone
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
-from streamlit.proto.Slider_pb2 import Slider as SliderProto
+from datetime import date, time, datetime, timedelta, timezone
+from typing import cast
+
+import streamlit
 from streamlit.errors import StreamlitAPIException
 from streamlit.js_number import JSNumber
 from streamlit.js_number import JSNumberBoundsException
-from .utils import _get_widget_ui_value
+from streamlit.proto.Slider_pb2 import Slider as SliderProto
+from .utils import register_widget
 
 
 class SliderMixin:
     def slider(
-        dg,
+        self,
         label,
         min_value=None,
         max_value=None,
@@ -202,6 +218,11 @@ class SliderMixin:
         if format is None:
             format = DEFAULTS[data_type]["format"]
 
+        if step == 0:
+            raise StreamlitAPIException(
+                "Slider components cannot be passed a `step` of 0."
+            )
+
         # Ensure that all arguments are of the same type.
         args = [min_value, max_value, step]
         int_args = all(map(lambda a: isinstance(a, int), args))
@@ -352,7 +373,7 @@ class SliderMixin:
         slider_proto.data_type = data_type
         slider_proto.options[:] = []
 
-        ui_value = _get_widget_ui_value("slider", slider_proto, user_key=key)
+        ui_value = register_widget("slider", slider_proto, user_key=key)
         if ui_value:
             current_value = getattr(ui_value, "data")
         else:
@@ -372,4 +393,9 @@ class SliderMixin:
             ]
         # If the original value was a list/tuple, so will be the output (and vice versa)
         return_value = current_value[0] if single_value else tuple(current_value)
-        return dg._enqueue("slider", slider_proto, return_value)  # type: ignore
+        return self.dg._enqueue("slider", slider_proto, return_value)
+
+    @property
+    def dg(self) -> "streamlit.delta_generator.DeltaGenerator":
+        """Get our DeltaGenerator."""
+        return cast("streamlit.delta_generator.DeltaGenerator", self)
