@@ -1,3 +1,17 @@
+# Copyright 2018-2021 Streamlit Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import textwrap
 
 from streamlit import type_util
@@ -6,7 +20,7 @@ from streamlit.errors import DuplicateWidgetID
 from typing import Optional, Any
 
 
-class NoValue(object):
+class NoValue:
     """Return this from DeltaGenerator.foo_widget() when you want the st.foo_widget()
     call to return None. This is needed because `DeltaGenerator._enqueue`
     replaces `None` with a `DeltaGenerator` (for use in non-widget elements).
@@ -15,7 +29,8 @@ class NoValue(object):
     pass
 
 
-def _clean_text(text):
+def clean_text(text: Any) -> str:
+    """Convert an object to text, dedent it, and strip whitespace."""
     return textwrap.dedent(str(text)).strip()
 
 
@@ -50,34 +65,13 @@ def _build_duplicate_widget_message(
     return message.strip("\n").format(widget_type=widget_func_name, user_key=user_key)
 
 
-def _set_widget_id(
-    element_type: str,
-    element_proto: Any,
-    user_key: Optional[str] = None,
-    widget_func_name: Optional[str] = None,
-) -> None:
-    """Set the widget id.
-
-    Parameters
-    ----------
-    element_type : str
-        The type of the element as stored in proto.
-    element_proto : proto
-        The proto of the specified type (e.g. Button/Multiselect/Slider proto)
-    user_key : str or None
-        Optional user-specified key to use for the widget ID.
-        If this is None, we'll generate an ID by hashing the element.
-    widget_func_name : str or None
-        The widget's DeltaGenerator function name, if it's different from
-        its element_type. Custom components are a special case: they all have
-        the element_type "component_instance", but are instantiated with
-        dynamically-named functions.
+def _get_widget_id(
+    element_type: str, element_proto: Any, user_key: Optional[str] = None
+) -> str:
+    """Generate the widget id for the given widget.
 
+    Does not mutate the element_proto object.
     """
-
-    if widget_func_name is None:
-        widget_func_name = element_type
-
     # Identify the widget with a hash of type + contents
     element_hash = hash((element_type, element_proto.SerializeToString()))
     if user_key is not None:
@@ -85,30 +79,23 @@ def _set_widget_id(
     else:
         widget_id = "%s" % element_hash
 
-    ctx = get_report_ctx()
-    if ctx is not None:
-        added = ctx.widget_ids_this_run.add(widget_id)
-        if not added:
-            raise DuplicateWidgetID(
-                _build_duplicate_widget_message(widget_func_name, user_key)
-            )
-    element_proto.id = widget_id
+    return widget_id
 
 
-def _get_widget_ui_value(
+def register_widget(
     element_type: str,
     element_proto: Any,
     user_key: Optional[str] = None,
     widget_func_name: Optional[str] = None,
 ) -> Any:
-    """Get the widget ui_value from the report context.
+    """Register a widget with Streamlit, and return its current ui_value.
     NOTE: This function should be called after the proto has been filled.
 
     Parameters
     ----------
     element_type : str
         The type of the element as stored in proto.
-    element : proto
+    element_proto : proto
         The proto of the specified type (e.g. Button/Multiselect/Slider proto)
     user_key : str
         Optional user-specified string to use as the widget ID.
@@ -127,10 +114,29 @@ def _get_widget_ui_value(
         doesn't exist, None will be returned.
 
     """
-    _set_widget_id(element_type, element_proto, user_key, widget_func_name)
+    widget_id = _get_widget_id(element_type, element_proto, user_key)
+    element_proto.id = widget_id
+
     ctx = get_report_ctx()
-    ui_value = ctx.widgets.get_widget_value(element_proto.id) if ctx else None
-    return ui_value
+    if ctx is None:
+        # Early-out if we're not running inside a ReportThread (which
+        # probably means we're running as a "bare" Python script, and
+        # not via `streamlit run`).
+        return None
+
+    # Register the widget, and ensure another widget with the same id hasn't
+    # already been registered.
+    added = ctx.widget_ids_this_run.add(widget_id)
+    if not added:
+        raise DuplicateWidgetID(
+            _build_duplicate_widget_message(
+                widget_func_name if widget_func_name is not None else element_type,
+                user_key,
+            )
+        )
+
+    # Return the widget's current value.
+    return ctx.widgets.get_widget_value(widget_id)
 
 
 def last_index_for_melted_dataframes(data):
