@@ -1,4 +1,4 @@
-# Copyright 2018-2020 Streamlit Inc.
+# Copyright 2018-2021 Streamlit Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -176,27 +176,82 @@ def _is_magicmock(obj):
     )
 
 
+class _Cells:
+    """
+    This is basically a dict that allows us to push/pop frames of data.
+
+    Python code objects are nested. In the following function:
+
+        @st.cache()
+        def func():
+            production = [[x + y for x in range(3)] for y in range(5)]
+            return production
+
+    func.__code__ is a code object, and contains (inside
+    func.__code__.co_consts) additional code objects for the list
+    comprehensions. Those objects have their own co_freevars and co_cellvars.
+
+    What we need to do as we're traversing this "tree" of code objects is to
+    save each code object's vars, hash it, and then restore the original vars.
+    """
+
+    _cell_delete_obj = object()
+
+    def __init__(self):
+        self.values = {}
+        self.stack = []
+        self.frames = []
+
+    def _set(self, key, value):
+        """
+        Sets a value and saves the old value so it can be restored when
+        we pop the frame. A sentinel object, _cell_delete_obj, indicates that
+        the key was previously empty and should just be deleted.
+        """
+
+        # save the old value (or mark that it didn't exist)
+        self.stack.append((key, self.values.get(key, self._cell_delete_obj)))
+
+        # write the new value
+        self.values[key] = value
+
+    def pop(self):
+        """Pop off the last frame we created, and restore all the old values."""
+
+        idx = self.frames.pop()
+        for key, val in self.stack[idx:]:
+            if val is self._cell_delete_obj:
+                del self.values[key]
+            else:
+                self.values[key] = val
+        self.stack = self.stack[:idx]
+
+    def push(self, code, func=None):
+        """Create a new frame, and save all of `code`'s vars into it."""
+
+        self.frames.append(len(self.stack))
+
+        for var in code.co_cellvars:
+            self._set(var, var)
+
+        if code.co_freevars:
+            if func is not None:
+                assert len(code.co_freevars) == len(func.__closure__)
+                for var, cell in zip(code.co_freevars, func.__closure__):
+                    self._set(var, cell.cell_contents)
+            else:
+                # List comprehension code objects also have freevars, but they
+                # don't have a surrouding closure. In these cases we just use the name.
+                for var in code.co_freevars:
+                    self._set(var, var)
+
+
 def _get_context(func) -> Context:
-    code = func.__code__  # type: types.CodeType
-
-    # Mapping from variable name to the value if we can resolve it.
-    # Otherwise map to the name.
-    cells = {}
-
-    for var in code.co_cellvars:
-        cells[var] = var  # Instead of value, we use the name.
-
-    if code.co_freevars:
-        assert len(code.co_freevars) == len(func.__closure__)
-        cells.update(
-            zip(code.co_freevars, map(lambda c: c.cell_contents, func.__closure__))  # type: ignore[no-any-return]
-        )
-
     varnames = {}
     if inspect.ismethod(func):
         varnames = {"self": func.__self__}
 
-    return Context(globals=func.__globals__, cells=cells, varnames=varnames)
+    return Context(globals=func.__globals__, cells=_Cells(), varnames=varnames)
 
 
 def _int_to_bytes(i):
@@ -546,7 +601,7 @@ class _CodeHasher:
                 context = _get_context(obj)
                 if obj.__defaults__:
                     self.update(h, obj.__defaults__, context)
-                h.update(self._code_to_bytes(obj.__code__, context))
+                h.update(self._code_to_bytes(obj.__code__, context, func=obj))
             else:
                 # Don't hash code that is not in the current working directory.
                 self.update(h, obj.__module__)
@@ -597,7 +652,7 @@ class _CodeHasher:
                 self.update(h, item, context)
             return h.digest()
 
-    def _code_to_bytes(self, code, context):
+    def _code_to_bytes(self, code, context, func=None):
         h = hashlib.new("md5")
 
         # Hash the bytecode.
@@ -611,8 +666,10 @@ class _CodeHasher:
         ]
         self.update(h, consts, context)
 
+        context.cells.push(code, func=func)
         for ref in get_referenced_objects(code, context):
             self.update(h, ref, context)
+        context.cells.pop()
 
         return h.digest()
 
@@ -662,7 +719,7 @@ def get_referenced_objects(code, context):
                 else:
                     set_tos(op.argval)
             elif op.opname in ["LOAD_DEREF", "LOAD_CLOSURE"]:
-                set_tos(context.cells[op.argval])
+                set_tos(context.cells.values[op.argval])
             elif op.opname == "IMPORT_NAME":
                 try:
                     set_tos(importlib.import_module(op.argval))
