@@ -1,4 +1,4 @@
-# Copyright 2018-2020 Streamlit Inc.
+# Copyright 2018-2021 Streamlit Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -39,7 +39,7 @@ from streamlit.proto.ClientState_pb2 import ClientState
 from streamlit.server.server_util import serialize_forward_msg
 from streamlit.storage.file_storage import FileStorage
 from streamlit.watcher.local_sources_watcher import LocalSourcesWatcher
-import streamlit.elements.exception_proto as exception_proto
+import streamlit.elements.exception as exception
 
 LOGGER = get_logger(__name__)
 
@@ -193,7 +193,7 @@ class ReportSession(object):
         self._on_scriptrunner_event(ScriptRunnerEvent.SCRIPT_STOPPED_WITH_SUCCESS)
 
         msg = ForwardMsg()
-        exception_proto.marshall(msg.delta.new_element.exception, e)
+        exception.marshall(msg.delta.new_element.exception, e)
 
         self.enqueue(msg)
 
@@ -296,10 +296,10 @@ class ReportSession(object):
                 )
             else:
                 # When a script fails to compile, we send along the exception.
-                from streamlit.elements import exception_proto
+                import streamlit.elements.exception as exception_utils
 
                 msg = ForwardMsg()
-                exception_proto.marshall(
+                exception_utils.marshall(
                     msg.session_event.script_compilation_exception, exception
                 )
                 self.enqueue(msg)
@@ -401,6 +401,7 @@ class ReportSession(object):
         imsg.user_info.installation_id = Installation.instance().installation_id
         imsg.user_info.installation_id_v1 = Installation.instance().installation_id_v1
         imsg.user_info.installation_id_v2 = Installation.instance().installation_id_v2
+        imsg.user_info.installation_id_v3 = Installation.instance().installation_id_v3
         if Credentials.get_current().activation:
             imsg.user_info.email = Credentials.get_current().activation.email
         else:
