@@ -1,4 +1,4 @@
-# Copyright 2018-2020 Streamlit Inc.
+# Copyright 2018-2021 Streamlit Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,18 +12,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Dict, Any
-from typing import List
+from typing import Any, Callable, Dict, List
 
 import tornado.httputil
 import tornado.web
 
-from streamlit.uploaded_file_manager import UploadedFileRec
+from streamlit.uploaded_file_manager import UploadedFileRec, UploadedFileManager
 from streamlit import config
 from streamlit.logger import get_logger
 from streamlit.report import Report
 from streamlit.server import routes
 
+
+# /upload_file/(optional session id)/(optional widget id)/(optional file_id of digits)
+UPLOAD_FILE_ROUTE = (
+    "/upload_file/?(?P<session_id>[^/]*)?/?(?P<widget_id>[^/]*)?/?(?P<file_id>[0-9]*)?"
+)
 LOGGER = get_logger(__name__)
 
 
@@ -32,19 +36,25 @@ class UploadFileRequestHandler(tornado.web.RequestHandler):
     Implements the POST and DELETE /upload_file endpoint.
     """
 
-    def initialize(self, file_mgr):
+    def initialize(
+        self, file_mgr: UploadedFileManager, get_session_info: Callable[[str], bool]
+    ):
         """
         Parameters
         ----------
         file_mgr : UploadedFileManager
             The server's singleton UploadedFileManager. All file uploads
             go here.
-
+        get_session_info: Server.get_session_info. Used to validate session IDs
         """
         self._file_mgr = file_mgr
+        self._get_session_info = get_session_info
+
+    def _validate_request(self, session_id: str):
+        return self._get_session_info(session_id) is not None
 
     def set_default_headers(self):
-        self.set_header("Access-Control-Allow-Methods", "POST, PUT, DELETE")
+        self.set_header("Access-Control-Allow-Methods", "POST, DELETE")
         self.set_header("Access-Control-Allow-Headers", "Content-Type")
         if config.get_option("server.enableXsrfProtection"):
             self.set_header(
@@ -110,6 +120,9 @@ class UploadFileRequestHandler(tornado.web.RequestHandler):
         try:
             session_id = self._require_arg(args, "sessionId")
             widget_id = self._require_arg(args, "widgetId")
+            if not self._validate_request(session_id):
+                raise Exception("Session '%s' invalid" % session_id)
+
         except Exception as e:
             self.send_error(400, reason=str(e))
             return
@@ -136,6 +149,17 @@ class UploadFileRequestHandler(tornado.web.RequestHandler):
             return
         replace = self.get_argument("replace", "false")
 
+        try:
+            total_files = int(self._require_arg(args, "totalFiles"))
+        except Exception as e:
+            total_files = 1
+
+        self._file_mgr.update_file_count(
+            session_id=session_id,
+            widget_id=widget_id,
+            file_count=total_files,
+        )
+
         update_files = (
             self._file_mgr.replace_files
             if replace == "true"
@@ -153,26 +177,19 @@ class UploadFileRequestHandler(tornado.web.RequestHandler):
 
         self.set_status(200)
 
-    def put(self, session_id: str, widget_id: str, **kwargs):
-        if self.request.body:
-            data = tornado.escape.json_decode(self.request.body)
-            if "totalFiles" in data.keys():
-                self._file_mgr.update_file_count(
-                    session_id=session_id,
-                    widget_id=widget_id,
-                    file_count=data["totalFiles"],
-                )
-                self.set_status(200)
-                return
-
-        self.send_error(400, reason="Nothing to update")
-
     def delete(self, session_id, widget_id, file_id):
-        if session_id is None or widget_id is None or file_id is None:
+        if not all(
+            [session_id, widget_id, file_id, self._validate_request(session_id)]
+        ):
             self.send_error(404)
             return
 
         try:
+            self._file_mgr.decrement_file_count(
+                session_id=session_id,
+                widget_id=widget_id,
+                decrement_by=1,
+            )
             self._file_mgr.remove_file(
                 session_id=session_id,
                 widget_id=widget_id,
